@@ -6,8 +6,8 @@
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 1.8.4
-;; Package-Revision: v1.8.4-0-g7d8fd72222b7
+;; Package-Version: 1.8.5
+;; Package-Revision: v1.8.5-0-g3b1d39d6b37f
 ;; Package-Requires: (
 ;;     (emacs  "26.1")
 ;;     (compat "30.1"))
@@ -204,7 +204,8 @@ This variable has to be set before `no-littering' is loaded.")
     (eval-after-load 'newsticker  `(make-directory ,(var "newsticker/") t))
     (eval-after-load 'org         `(make-directory ,(var "org/") t))
     (eval-after-load 'shadowfile  `(make-directory ,(var "shadow/") t))
-    (eval-after-load 'treesit     `(push ,(var "treesit/") treesit-extra-load-path))
+    (eval-after-load 'treesit     `(when (treesit-available-p)
+                                     (push ,(var "treesit/") treesit-extra-load-path)))
 
 ;;; Third-party packages
 
@@ -306,10 +307,12 @@ This variable has to be set before `no-littering' is loaded.")
     (setq lsp-session-file                 (var "lsp/session.el"))
     (setq magithub-cache-file              (var "magithub/cache.el"))
     (setq magithub-dir                     (var "magithub/"))
+    (setq mason-dir                        (var "mason/"))
     (setq mastodon-client--token-file      (var "mastodon-client--token"))
     (setq mc/list-file                     (var "mc-list.el"))
     (setq meghanada-server-install-dir     (var "meghanada/"))
     (setq multi-compile-history-file       (var "multi-compile-history.el"))
+    (setq neocaml-repl-history-file        (var "neocaml-repl-history"))
     (setq nix-buffer-directory-name        (var "nix-buffer/"))
     (setq nomad-tramp-script-directory     (var "nomad-tramp/"))
     ;; The value of this variable MUST NOT end with ".el" but the
